@@ -28,4 +28,4 @@ if __name__ == 'fgp':
 
     # add ch to logger
     logger.addHandler(ch)
-    logger.info('Configured logger')
\ No newline at end of file
+    # logger.info('Configured logger')
\ No newline at end of file
