@@ -45,8 +45,8 @@ def register(client: ApiClient, module: Module):
 
 
 def get_run(client: ApiClient, device_name: str, run_id: int) -> ModuleState:
-    date_from = datetime.datetime.utcfromtimestamp(run_id/1000-1)
-    date_to = datetime.datetime.utcfromtimestamp(run_id/1000+1)
+    date_from = datetime.datetime.utcfromtimestamp(run_id/1000) - datetime.timedelta(days=1)
+    date_to = datetime.datetime.utcfromtimestamp(run_id/1000) + datetime.timedelta(days=1)
     ret = client.store.get_data(
         device_type='module',
         date_from=date_from,
@@ -54,9 +54,12 @@ def get_run(client: ApiClient, device_name: str, run_id: int) -> ModuleState:
         store_name='module_run',
         devices=[device_name]
     )
+    if ret is None:
+        raise ValueError(f'Run with run_id={run_id} not found, no results returned from API when using date_from={date_from}, date_to={date_to}')
+    ret = ret[ret['timeKey'] == run_id]
     if len(ret["doc"]) == 0:
-        raise ValueError(f'Run with run_id={run_id} not found, used date_from={date_from}, date_to={date_to}')
-    data_str = ret["doc"][0]
+        raise ValueError(f'Run with run_id={run_id} not found, filtered result set was empty when using date_from={date_from}, date_to={date_to}. Full results {ret}.')
+    data_str = ret[["doc"]].to_dict(orient='records')[0]['doc']
     if not data_str:
         raise ValueError(f'Invalid run, no data found in "doc" field {ret}')
     data = json.loads(data_str)
