@@ -18,11 +18,12 @@ class Relation:
             device_type: str,
             device_name: str,
             relation_name: str,
-            timestamp: datetime.datetime = None
+            timestamp: datetime.datetime = None,
+            is_parent=False
     ) -> dict:
-        params = {
-            'isParent': True
-        }
+        params = {}
+        if is_parent:
+            params['isParent'] = True
         if timestamp:
             params['timestamp']: datetime_to_ms(timestamp)
         res = self._client.get(route=f'{device_type}/{device_name}/relation/{relation_name}', params=params)
